summaryrefslogtreecommitdiff
path: root/tools/dump_cinit.lua
diff options
context:
space:
mode:
authorJosh Haberman <jhaberman@gmail.com>2014-01-21 18:38:49 -0800
committerJosh Haberman <jhaberman@gmail.com>2014-01-21 18:38:49 -0800
commit0fd2f830882402979a83010e89650e7245960d39 (patch)
tree0968ca9424c5fb2433047519cbd54d3dd8d0b863 /tools/dump_cinit.lua
parentce9bba3cb5409844f8f3d7dcc235a9ea30cad090 (diff)
Sync to internal Google development.
Diffstat (limited to 'tools/dump_cinit.lua')
-rw-r--r--tools/dump_cinit.lua11
1 files changed, 6 insertions, 5 deletions
diff --git a/tools/dump_cinit.lua b/tools/dump_cinit.lua
index c83aa04..e23e907 100644
--- a/tools/dump_cinit.lua
+++ b/tools/dump_cinit.lua
@@ -359,13 +359,14 @@ local function dump_defs_c(symtab, basename, append)
else
intfmt = "0"
end
- -- UPB_FIELDDEF_INIT(label, type, intfmt, tagdelim, name, num, msgdef,
- -- subdef, selector_base, index, default_value)
- append(' UPB_FIELDDEF_INIT(%s, %s, %s, %s, "%s", %d, %s, %s, %d, %d, ' ..
- '{0},' .. -- TODO: support default value
+ -- UPB_FIELDDEF_INIT(label, type, intfmt, tagdelim, is_extension, name,
+ -- num, msgdef, subdef, selector_base, index,
+ -- default_value)
+ append(' UPB_FIELDDEF_INIT(%s, %s, %s, %s, %s, "%s", %d, %s, %s, %d, ' ..
+ '%d, {0},' .. -- TODO: support default value
'&reftables[%d], &reftables[%d]),\n',
const(f, "label"), const(f, "type"), intfmt,
- boolstr(f:istagdelim()), f:name(),
+ boolstr(f:istagdelim()), boolstr(f:is_extension()), f:name(),
f:number(), linktab:addr(f:containing_type()), subdef,
f:_selector_base(), f:index(),
reftable, reftable + 1
generated by cgit on debian on lair
contact matthew@masot.net with questions or feedback